import { program as app, Command } from '@/program.ts';
import { getConfig, query, writeConfig } from '@/module/index.ts';
import inquirer from 'inquirer';

const token = new Command('token').description('show token').action(async () => {
  const config = getConfig();
  console.log('token', config.token);
});

app.addCommand(token);

const baseURL = new Command('baseURL')
  .alias('base')
  .description('show baseURL')
  .option('-a, --add <baseURL>', 'add baseURL')
  .option('-r, --remove <number>', 'remove baseURL number')
  .option('-s, --set <number>', 'set current baseURL')
  .option('-l, --list', 'list baseURL')
  .option('-c, --clear', 'clear baseURL')
  .action(async (opts) => {
    const config = getConfig();
    let list = config.baseURLList || [];
    const quineList = (list: string[]) => {
      const newList = new Set(list);
      return Array.from(newList);
    };
    const showList = (list: string[]) => {
      if (list.length === 0) {
        console.log('expand baseURLList is empty');
        return;
      }
      console.log('----current baseURL:' + config.baseURL+'----\n');
      list.forEach((item, index) => {
        console.log(`${index + 1}: ${item}`);
      });
    };
    if (opts.add) {
      list.push(opts.add);
      list = quineList(list);
      console.log('add baseURL success\n');
      writeConfig({ ...config, baseURLList: list });
      showList(list);
      return;
    }
    if (opts.remove) {
      const index = Number(opts.remove) - 1;
      if (index < 0 || index >= list.length) {
        console.log('index out of range');
        return;
      }
      list.splice(index, 1);
      list = quineList(list);
      showList(list);
      writeConfig({ ...config, baseURLList: list });
      return;
    }
    if (opts.set) {
      const index = Number(opts.set) - 1;
      if (index < 0 || index >= list.length) {
        console.log('index out of range');
      }
      writeConfig({ ...config, baseURL: list[index] });
      console.log('set baseURL success:', list[index]);
      return;
    }
    if (opts.list) {
      showList(list);
      return;
    }
    if (opts.clear) {
      writeConfig({ ...config, baseURLList: [] });
      return;
    }
    console.log('current baseURL:', config.baseURL);
  });
app.addCommand(baseURL);

const setBaseURL = new Command('setBaseURL').description('set baseURL').action(async () => {
  const config = getConfig();
  const answers = await inquirer.prompt([
    {
      type: 'input',
      name: 'baseURL',
      message: `Enter your baseURL:(current: ${config.baseURL})`,
    },
  ]);
  const baseURL = answers.baseURL;
  writeConfig({ ...config, baseURL });
});

app.addCommand(setBaseURL);

// const showQueryURL = new Command('showQueryURL').description('show query URL').action(async () => {
//   console.log("url", query.url);
// });

// app.addCommand(showQueryURL);
